@@ -1,5 +1,5 @@
 package Sim::OPT::Descend;
-# Copyright (C) 2008-2025 by Gian Luca Brunetti, gianluca.brunetti@gmail.com.
+# Copyright (C) 2008-2022 by Gian Luca Brunetti.
 # This is the module Sim::OPT::Descend of Sim::OPT, a program for detailed metadesign managing parametric explorations through the ESP-r building performance simulation platform and performing optimization by block coordinate descent.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
@@ -43,7 +43,7 @@ no warnings;
 
 our @EXPORT = qw( descend prepareblank tee repcache ); # our @EXPORT = qw( );
 
-$VERSION = '0.171'; # our $VERSION = '';
+$VERSION = '0.169'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Descent is an module collaborating with the Sim::OPT module for performing block coordinate descent.';
 
 #########################################################################################
@@ -372,11 +372,11 @@ sub descend
 
   sub cleanselect
   {   # IT CLEANS THE MIXED FILE AND SELECTS SOME COLUMNS, THEN COPIES THEM IN ANOTHER FILE
-    my ( $repfile, $selectmixed, $inst_r, $countblock, $varnums_r, $blockelts_r, $from, $dirfiles_r ) = @_;
+    my ( $repfile, $selectmixed, $inst_r, $countblock, $varnums_r, $blockelts_r, $from, $dowhat_r ) = @_;
     $inst_r ||= {};
     my %varnums = %$varnums_r; #say $tee "IN DESCENT \@blockelts  " . dump( @blockelts );
     my @blockelts = @$blockelts_r;
-    my %dirfiles = %$dirfiles_r;
+    my %dowhat = %$dowhat_r;
 
     #say $tee "IN DESCENT \@blockelts " . dump( @blockelts );
     my $expected_r = Sim::OPT::enumerate(\%varnums, \@blockelts, $from); #say $tee "IN DESCENT \$countblock $countblock \$expected_r " . dump( $expected_r );
@@ -397,8 +397,8 @@ sub descend
       my $id = Sim::OPT::instid( $ln, $file ); say $tee "IN DESCENT \$countblock $countblock \$id " . dump( $id );# NOT $repfile
       if ( defined($id) and $id ne "" )
       {
-        $dirfiles{reps}{$id} = $ln; #say $tee "IN DESCENT WRITING \$dirfiles{reps}{\$id} \$dirfiles{reps}{$id} " . dump( $dirfiles{reps}{$id} );# NOT $repfile
-        $present{$id} = 1; #say $tee "IN DESCENT \$countblock $countblock \$present{\$id} \$present{$id} " . dump( $present{$id} );# NOT $repfile
+        $dirfiles{reps}{$id} = $ln; say $tee "IN DESCENT WRITING \$dirfiles{reps}{\$id} \$dirfiles{reps}{$id} " . dump( $dirfiles{reps}{$id} );# NOT $repfile
+        $present{$id} = 1; say $tee "IN DESCENT \$countblock $countblock \$present{\$id} \$present{$id} " . dump( $present{$id} );# NOT $repfile
       }
     }
 
@@ -501,8 +501,8 @@ sub descend
           $dirfiles{countnettotrowlength}++; #THIS CALCULATES THE LENGTH OF THE ROW AND STORES IT
         }
         
-
-        unless ( $obtaineds[-1] eq $dirfiles{discard} )
+        say $tee "IN DESCEND \$dowhat{discard} $dowhat{discard}";
+        unless ( $obtaineds[-1] eq $dowhat{discard} )
         {
           print SELECTEDMIXED "$touse,";
 
@@ -529,10 +529,10 @@ sub descend
 
   if ( $precomputed eq "" )###DDD!!!
   {
-    cleanselect( $repfile, $selectmixed, \%inst, $countblock, \%varnums, \@blockelts, $from, \%dirfiles );
+    cleanselect( $repfile, $selectmixed, \%inst, $countblock, \%varnums, \@blockelts, $from, \%dowhat );
   }
 
-  say $tee "IN DESCEND AFTER CLEANSELECT; INST " . dump( %inst );
+  say $tee "IN DESCEND AFTER CLEANSELECT; INST " . dump( \%inst );
 
 
   my $throw = $selectmixed;
@@ -2117,11 +2117,11 @@ An example of configuration file for block search ("des.pl") is packed in "optw.
 
 =head1 AUTHOR
 
-Gian Luca Brunetti, E<lt>, gianluca.brunetti@gmail.comE<gt>
+Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008-2022 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This is free software. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
+Copyright (C) 2008-2022 by Gian Luca Brunetti. This is free software. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 
 =cut
