@@ -1,5 +1,5 @@
 package Sim::OPT::Parcoord3d;
-# Copyright (C) 2015 by Gian Luca Brunetti, gianluca.brunetti@gmail.com.
+# Copyright (C) 2015 by Gian Luca Brunetti.
 # This is Sim::OPT::Parcoord3d, a program that can receive as input the data for a bi-dimensional parallel coordinate plot in cvs format to produce as output an Autolisp file that can be used from Autocad or Intellicad-based 3D CAD programs to obtain 3D parallel coordinate plots.
 # This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
@@ -522,11 +522,11 @@ An example of configuration instructions for Sim::OPT::Parcoord3d is included in
 
 =head1 AUTHOR
 
-Gian Luca Brunetti, E<lt>gianluca.brunetti@gmail.comE<gt>
+Gian Luca Brunetti, E<lt>gianluca.brunetti@polimi.itE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2015-2016 by Gian Luca Brunetti, gianluca.brunetti@gmail.com. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
+Copyright (C) 2015-2016 by Gian Luca Brunetti. This is free software.  You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, version 3.
 
 
 =cut
